<?php
/*

Module: Tei
File: TeiExplor.php
This file contents Php function dealing with TEI items in an Explor context

 */

function TeiGetTitle(&$paramTable,&$domRecord, $teiRoot)
        {
          if ($teiRoot) 
	    {
	      $titlePath = new DOMXPath($domRecord);
	      $query="teiHeader/fileDesc/titleStmt/title";
	      if ($lTitle=$titlePath->query($query,$teiRoot))
		{
		  $title=$lTitle->item(0);
		  return $title->nodeValue;
		}
	    }
	  return false;
	}

function TeiGetDateWhen(&$paramTable,&$domRecord, $teiRoot)
        {
          if ($teiRoot) 
	    {
	      $datePath = new DOMXPath($domRecord);
	      $query="teiHeader/fileDesc/publicationStmt/date";
	      if ($lDate=$datePath->query($query,$teiRoot))
		{
		  $nDate=$lDate->item(0);
		  if (!$nDate)return NULL;
		  $date=$nDate->getAttribute("when");
		  return $date;
		}
	    }
	  return false;
	}

function TeiGetUrlSet(&$paramTable,&$domRecord, $teiRoot)
{
  if ($teiRoot) 
    {
      $urlPath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/publicationStmt/idno[@type='url']";
      if ($lUrl=$urlPath->query($query,$teiRoot))
	{
	  if($lUrl->length>0) return $lUrl;
	}
	/*
	{
	  if($lUrl->length>0) return $lUrl->item(0)->nodeValue;
	}
	*/
    }
  return NULL;
}

function TeiGetDoi(&$paramTable,&$domRecord, $teiRoot)
{
  if ($teiRoot) 
    {
      $urlPath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/publicationStmt/idno[@type='doi']";
      if ($lUrl=$urlPath->query($query,$teiRoot))
	{
	   if($lUrl->length>0) return $lUrl->item(0)->nodeValue;
	}
    }
  return NULL;
}

function TeiGetPmid(&$paramTable,&$domRecord, $teiRoot)
{
  if ($teiRoot) 
    {
      $urlPath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/publicationStmt/idno[@type='pmid']";
      if ($lUrl=$urlPath->query($query,$teiRoot))
	{
	   if($lUrl->length>0) return $lUrl->item(0)->nodeValue;
	}
    }
  return NULL;
}

function TeiGetPmc(&$paramTable,&$domRecord, $teiRoot)
{
  if ($teiRoot) 
    {
      $urlPath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/publicationStmt/idno[@type='pmc']";
      if ($lUrl=$urlPath->query($query,$teiRoot))
	{
	   if($lUrl->length>0) return $lUrl->item(0)->nodeValue;
	}
    }
  return NULL;
}


function TeiGetRbid(&$paramTable,&$domRecord, $teiRoot)
{
  if ($teiRoot) 
    {
      $urlPath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/publicationStmt/idno[@type='RBID']";
      if ($lUrl=$urlPath->query($query,$teiRoot))
	{
	   if($lUrl->length>0) return $lUrl->item(0)->nodeValue;
	}
    }
  return NULL;
}

function TeiGetAbstractNode(&$paramTable,&$domRecord, $teiRoot, $lang)
{
  if ($teiRoot) 
    {
      $abstractPath = new DOMXPath($domRecord);
      $query="front/div";
      /*      $query="front/div[@type='abstract']"; */
      if ($lAbstract=$abstractPath->query($query,$teiRoot))
	{
	   if($lAbstract->length>0)
	     {
	       return $lAbstract->item(0);
	     }
	}
    }
  return NULL;
}

function TeiGetSourceBiblNode(&$paramTable,&$domRecord, $teiRoot)
{
    if ($teiRoot) 
    {
      $sourcePath = new DOMXPath($domRecord);
      $query="teiHeader/fileDesc/sourceDesc/biblStruct";
      if ($lSourceBibl=$sourcePath->query($query,$teiRoot))
	{
	   if($lSourceBibl->length>0)
	     {
	       return $lSourceBibl->item(0);
	     }
	}
    }
  return NULL;
}

function TeiExplorRecordPrintKeywords(&$paramTable,&$domRecord, $stream, $step, $lang, $lkw)
{
  $oldLang=NULL;
  foreach ($lkw as $kw)
    {
      $kwLang=$kw->getAttribute("xml:lang") ;
      echo "<!--".$kwLang."-->";
      if ( $kwLang != $lang) continue;
      if (! $oldLang)
	{
	  $oldLang=$lang;
	  if ($lang=="fr") echo "<h4>Descripteurs français</h4>\n";
	  else echo "<h4>English descriptors</h4>\n";
          echo "<ul>\n";
	  $oldScheme=NULL;
	}
      $kwScheme=$kw->getAttribute("scheme") ;
      $messScheme=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messKeywordsScheme".$kwScheme);
	  if (!$messScheme)$messScheme=$kwScheme." :";
      if (($oldScheme)&&(strcmp($oldScheme,$kwScheme)!=0))
	{
	  echo ("</ul></li>");
	}
      if ((!$oldScheme) || (strcmp($oldScheme,$kwScheme)!=0))
	{
	  echo "<li><b>".$messScheme."</b>";
	  echo "<ul>";
	  $oldScheme=$kwScheme;
	}
      echo "<li>";
      $type=$kw->getAttribute("type") ;
      $qualifier=$kw->getAttribute("qualifier") ;
      if ($type)
	{	
	  $typeMess=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messKeywordsType".$type);
	  if (!$typeMess)$typeMess=$type;
	  echo "<b><i>".$type."</i></b> ";
	}
       if ($qualifier) 
	    {
	      if ($type) echo ", ";
	      echo "<i>".$qualifier ."</i> ";
	    }
       if ($type||$qualifier) echo " : ";
       $pageIndex=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "pageIndex".$kwScheme);
       if (!$pageIndex) $pagedIndex="indexItem.php?index=".$kwScheme.".i";
       if (($lang=="fr")&&($kwScheme=="MESH"))$pagedIndex="indexItem.php?index=MeshFr.i";
       if (($lang=="fr")&&($kwScheme=="Pascal"))$pagedIndex="indexItem.php?index=PascalFr.i";
       foreach($kw->childNodes as $term)
	 {
	   echo '<a href="'.$pagedIndex;
	   echo '&key='.$term->nodeValue.'">'.$term->nodeValue."</a>";
	   if ( $term->nextSibling) echo ", \n";
	   else echo ".";
	 }
       echo "</li>\n";
    }
  if ($oldLang)
    {
      echo ("</ul></li>");
      echo "</ul>\n";
    }
}

function TeiExplorRecordPrint(&$paramTable,&$domRecord, $stream, $step)
{
  if (!$domRecord) return NULL;
  $teiRoot=SxmlNodeGetFirstChildByTagName($domRecord->documentElement,"TEI");
  if (!$teiRoot) return NULL;
  echo  "<hr/><h3>".TeiGetTitle($paramTable, $domRecord, $teiRoot)."</h3>";
  echo "<b>Auteurs : </b>";
  ExplorPrintAuthorsCountry ($paramTable,$domRecord, $teiRoot, $stream, $step, "bibRecord.php");

  $sourceBibl=TeiGetSourceBiblNode($paramTable,$domRecord, $teiRoot);
  if ($sourceBibl)
    {
      echo "<h4>Source : </h4>\n";
      echo "<ul>\n";
      $seriesNode=SxmlNodeGetFirstChildByTagName($sourceBibl, "series");
      if ($seriesNode)
	{
	  print ("<li>\n");
	  $titleNode=SxmlNodeGetFirstChildByTagName($seriesNode, "title");
	  if ($titleNode) echo $titleNode->nodeValue;
	  $issnNode=SxmlNodeGetFirstChildByTagNameAttribute($seriesNode,"idno", "type", "ISSN");
	  if (!$issnNode)$issnNode=SxmlNodeGetFirstChildByTagNameAttribute($seriesNode,"idno", "type", "eISSN");
	  if ($issnNode) 
	    {
	      $indexISSN=ExplorGetParam($paramTable, "Area/".$stream."/".$step."/ISSN.i/indexType");
	      echo " [ ";
	      if ($indexISSN) echo '<a href="indexItem.php?index=ISSN.i&key='.$issnNode->nodeValue.'">';
	      echo $issnNode->nodeValue;
 	      if ($indexISSN) echo "</a>";
	      echo " ] ";
	    }
	  $imprintNode=SxmlNodeGetFirstChildByTagName($seriesNode,"imprint");
	  if ($imprintNode)
	    {
	      $date=SxmlNodeGetFirstChildByTagName($imprintNode,"date");
	      if ($date) echo " ; ".$date->nodeValue.".";
	    }
	  print ("</li>\n");
	}
      echo "</ul>\n";
    }

  $ExplorBiblioRecordRBID=TeiGetRBID($paramTable,$domRecord, $teiRoot);

  if( $ExplorBiblioRecordRBID)
    {
      print ("<b>RBID</b> : ".$ExplorBiblioRecordRBID."\n");
    }
  else print ("*** no RBID ***\n");

  $kwPath = new DOMXPath($domRecord);
  $query="teiHeader/profileDesc/textClass/keywords";
  if (($lkw=$kwPath->query($query,$teiRoot))
      &&($lkw->length>0)
      )
    {     
      TeiExplorRecordPrintKeywords($paramTable,$domRecord, $stream, $step, "fr", $lkw);
      TeiExplorRecordPrintKeywords($paramTable,$domRecord, $stream, $step, "en", $lkw);
      /*
      echo "<h4>".ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messBibRecKeywords")."</h4>\n";
      echo "<ul>\n";
      $oldScheme=NULL;

      $firstKwWicri=1;
      foreach ($lkw as $kw)
	{
	  $scheme=$kw->getAttribute("scheme") ;
	  if ($scheme != "Wicri") continue;
	  if ($oldScheme)
	    {
	      if ($oldScheme != "Wicri")
		{
		  if  ($oldSchemeIndent=="yes") echo ("</ul></li>");
		}
	    }
	  if ((!$oldScheme)||($oldScheme!="Wicri"))
	    {
	      echo "<li><b>Wicri :</b><ul>";
	      $oldSchemeIndent="yes";
	      $oldScheme="Wicri";
	    }
	  echo "<li>";
	  $type=$kw->getAttribute("type") ;
	  $typeMess=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messKeywordsType".$type);
	  if (!$typeMess)$typeMess=$type;
	  echo "<b><i>".$type." : </i></b> ";
	  foreach($kw->childNodes as $term)
	    {
	      echo '<a href="'.ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "pageIndex".$scheme);
	      echo '&key='.$term->nodeValue.'">'.$term->nodeValue."</a>";
	      if ( $term->nextSibling) echo ", ";
	      else echo ".";
	    }
	  echo "</li>";
	}
      foreach ($lkw as $kw)
	{
	  $scheme=$kw->getAttribute("scheme") ;
	  if ($scheme == "Wicri") continue;
	  if ($scheme == "KwdEn") continue;
	  $type=$kw->getAttribute("type") ;
	  $qualifier=$kw->getAttribute("qualifier") ;
	  $lang=$kw->getAttribute("xml:lang") ;
          $messScheme=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messKeywordsScheme".$scheme);
	  if (!$messScheme)$messScheme=$scheme." :";
	  if ($oldScheme)
	    {
	      if ($oldScheme !=$scheme)
		{
		  if  ($oldSchemeIndent=="yes") echo ("</ul></li>");
		}
	    }
	  if  ((!$oldScheme)||($oldScheme!=$scheme))
	    {
	      if ($type||$qualifier) 
		{
		  $oldSchemeIndent="yes";
		  echo "<li><b>".$messScheme."</b><ul><li>";
		}
	      else 
		{
		  echo "<li><b>".$messScheme."</b>";
		  $oldSchemeIndent="no";
		}
	      $oldScheme=$scheme;
	    }
	  else echo "<li>";
	  if ($type)  echo "<b><i>".$type."</i></b>";
	  if ($qualifier) 
	    {
	      if ($type) echo ", ";
	      echo "<i>".$qualifier ."</i> ";
	    }
	  if ($type||$qualifier) echo " : ";
	  foreach($kw->childNodes as $term)
	    {
	      if (($lang=="fr")&&($scheme=="MESH"))
		{
		  echo '<a href="'.ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "pageIndexMeshFr.i");
		}
	      else echo '<a href="'.ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "pageIndex".$scheme);
	      echo '&key='.$term->nodeValue.'">'.$term->nodeValue."</a>";
	      if ( $term->nextSibling) echo ", ";
	      else echo ".";
	    }
	  echo "</li>";
	}

      foreach ($lkw as $kw)
	{
	  $scheme=$kw->getAttribute("scheme") ;
	  if ($scheme != "KwdEn") continue;
	  if ($oldScheme &&  ($oldSchemeIndent=="yes")) echo ("</ul></li>");
	  $oldScheme="KwdEn";
	  $oldSchemeIndent="no";
          $messKwdEn=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "messKeywordsScheme".$scheme);
	  if (!$messKwdEn)$messKwdEn="Keywords (en)";
	  echo "<li>";
	  echo "<b>".$messKwdEn." : </b> ";
	    {
	      foreach($kw->childNodes as $term)
		{
		  $pagedIndexKwdEn=ExplorGetParamK5($paramTable, "Area", $stream, $step, "bibRecord.php", "pageIndex".$scheme);
		  if (!$pagedIndexKwdEn)$pagedIndexKwdEn="indexItem.php?index=KwdEn.i";
		  echo '<a href="'.$pagedIndexKwdEn;
		  echo '&key='.$term->nodeValue.'">'.$term->nodeValue."</a>";
		  if ( $term->nextSibling) echo ", ";
		  else echo ".";
		}
	    }
	  echo "</li>";
	}

      if ($oldScheme &&  ($oldSchemeIndent=="yes")) echo ("</ul></li>");
      echo "</ul>\n";
      */
    }
  if ($abstractNode=TeiGetAbstractNode($paramTable,$domRecord, $teiRoot, "fr"))
    {
      echo "<h4>Abstract</h4>";
      SxmlNodePrintHtmlLeafDiv($abstractNode);
    }
  if ($urlSet=TeiGetUrlSet($paramTable,$domRecord, $teiRoot))
    {
      echo '<br/><b>Url: </b><ul>';	 
      foreach($urlSet as $url)
	{
	  echo '<li><a href="'.$url->nodeValue.'">'.$url->nodeValue."</a></li>";
	}
      echo "</ul>";
    }
  if ($doi=TeiGetDoi($paramTable,$domRecord, $teiRoot))
    {
      echo '<br/><b>DOI: </b><a href="http://dx.doi.org/'.$doi.'">'.$doi."</a>\n";
    }
  if ($pmid=TeiGetPmid($paramTable,$domRecord, $teiRoot))
    {
      echo '<br/><b>PubMed: </b><a href="https://pubmed.ncbi.nlm.nih.gov/'.$pmid.'">'.$pmid."</a>\n";
    }
  if ($pmc=TeiGetPmc($paramTable,$domRecord, $teiRoot))
    {
      echo '<br/><b>PubMed Central: </b><a href="https://www.ncbi.nlm.nih.gov/pmc/articles/'.$pmc.'">'.$pmc."</a>\n";
    }
  return $domRecord;
}

function TeiExplorPrintListLinks( &$listTerm, $index)
{
  if ($listTerm)
    {
      echo "<li>";
      foreach($listTerm->childNodes as $term)
	{
	  echo '<a href="indexItem.php?index='.$index."&key=".$term->nodeValue.'">';
	  echo $term->nodeValue;
	  echo "</a>";
	  if ($term->nextSibling) echo ", "; 
	}
      echo "</li>\n";
    }
}

function TeiExplorRecordAffPrint(&$paramTable, &$list, $stream, $step)
{
  echo "\n<p><br/><b>Affiliations:</b><ul>\n";
  $countryList=SxmlNodeGetFirstChildByTagName($list, "country");
  if ($countryList)
    {
      echo "<li>";
      foreach($countryList->childNodes as $country)
	{
	  echo '<a href="indexItem.php?index=AffPays.i&key='.$country->nodeValue.'">';
	  echo $country->nodeValue;
	  echo "</a>";
	  if ($country->nextSibling) echo ", "; 
	}
      echo "</li>\n";
    }
  $regionList=SxmlNodeGetFirstChildByTagName($list, "region");
  /*  if ($countryList)
    {
      echo "<li>";
      foreach($regionList->childNodes as $region)
	{
	  echo '<a href="indexItem.php?index=AffRegion.i&key='.$region->nodeValue.'">';
	  echo $region->nodeValue;
	  echo "</a>";
	  if ($region->nextSibling) echo ", "; 
	}
      echo "</li>\n";
    }
  */
  TeiExplorPrintListLinks($regionList, "AffRegion.i");
  $cityList=SxmlNodeGetFirstChildByTagName($list, "settlement");
  TeiExplorPrintListLinks($cityList, "AffVille.i");
  $orgList=SxmlNodeGetFirstChildByTagName($list, "orgName");
  TeiExplorPrintListLinks($orgList, "AffOrg.i");
  echo "</ul></p>";
}

   ?>
